import json
import logging
import os
from pprint import pprint

import requests
import treefiles as tf

CONF_FNAME = tf.Str(os.path.expanduser("~")) / ".hpkerga_conf.yaml"


def get_token() -> str:
    fname = tf.f(__file__) / ".secret_token.json"
    if not tf.isfile(fname):
        tf.dump_json(fname, {})
    res = tf.load_json(fname)
    force = "access_token" not in res
    if not tf.greedy_download(fname, force=force):
        return res["access_token"]
    else:
        from getpass import getpass

        name = input("Usename: ")
        password = getpass()
        data = f"username={name}&password={password}"

        api_endpoint = "https://api.kerga.fr/u/please-give-me-a-token"
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/x-www-form-urlencoded",
        }
        r = requests.post(url=api_endpoint, headers=headers, data=data)
        tf.dump_str(fname, json.dumps(r.json()))
        return get_token()


def check_conf(path):
    if not tf.isfile(path):
        tf.copyFile(tf.f(__file__) / "empty_conf.yaml", path)


def send_config(yaml_path: str):
    check_conf(yaml_path)
    API_TOKEN = get_token()
    API_ENDPOINT = "https://api.kerga.fr/hp/set-my-data"

    headers = {
        "Accept": "application/json",
        "Content-Type": "application/json",
        "Authorization": "Bearer " + API_TOKEN,
    }
    data = tf.load_yaml(yaml_path)
    r = requests.post(url=API_ENDPOINT, headers=headers, json=data)
    log.info(f"Reponse ({r.status_code}): {r.json()}")


def check_file():
    API_TOKEN = get_token()
    API_ENDPOINT = "https://api.kerga.fr/hp/"

    headers = {
        "Accept": "application/json",
        "Content-Type": "application/json",
        "Authorization": "Bearer " + API_TOKEN,
    }
    r = requests.get(url=API_ENDPOINT, headers=headers)
    log.info("File:")
    pprint(r.json())


log = logging.getLogger(__name__)

if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO)
    log = tf.get_logger()

    # print(get_token())

    send_config(CONF_FNAME)
    # check_file()

    log.info("Correct, visit https://hp.kerga.fr")



import logging

import click
import treefiles as tf

from hpkerga.send_config import send_config, CONF_FNAME


@click.command()
@click.argument("name", type=str)
@click.option("--url", type=str, help="Url to link")
@click.option("--desc", type=str, help="Description of the entry (may be empty)")
@click.option("--image", type=str, help="Link to image logo")
@click.option("--group", type=str, help="Group")
def main(name, url, desc, image, group):
    if name != "send":

        group = tf.none(group, "New Group")
        data = dict(tf.load_yaml(CONF_FNAME))
        if group not in data:
            data[group] = {}

        key = name.lower().replace(" ", "_") + f"_{tf.get_string()}"
        data[group][key] = {
            "name": name,
            "url": url,
            "desc": desc,
            "photo": image,
        }

        tf.dump_yaml(CONF_FNAME, data)
    send_config(CONF_FNAME)
    log.info("Correct, visit https://hp.kerga.fr")


log = logging.getLogger(__name__)

if __name__ == "__main__":
    logging.basicConfig(level=logging.DEBUG)
    log = tf.get_logger()

    main()
